@@ -166,7 +166,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
         self.current_row = None
 
         self.__column_names = {0: "Address", 1: "Port/Service", 2: "Protocol", }
-        self.__services = list()
+        self.__services = []
 
         self.port_range_pattern = re.compile(r'\d+-\d+')
         self.service_port_pattern = re.compile(r'(\d*) \([a-zA-Z0-9-]*\)')
@@ -354,7 +354,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
             self.fw_changed = True
 
         conf = {"allow": allow,
-                "rules": list()
+                "rules": []
                 }
 
         conf['rules'].extend(self.children)
@@ -397,7 +397,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
 
         return self.createIndex(row, column, self.children[row])
 
-    def parent(self, child):  # pylint: disable=unused-argument,no-self-use
+    def parent(self, child):  # pylint: disable=unused-argument
         return QtCore.QModelIndex()
 
     # pylint: disable=invalid-name,unused-argument
@@ -408,7 +408,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
     def columnCount(self, parent=QtCore.QModelIndex()):
         return len(self.__column_names)
 
-    # pylint: disable=invalid-name,no-self-use
+    # pylint: disable=invalid-name
     def hasChildren(self, index=QtCore.QModelIndex()):
         parent_item = index.internalPointer()
         return parent_item is None
@@ -456,7 +456,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
         self.fw_changed = True
 
     def clear_children(self):
-        self.__children = list()
+        self.__children = []
 
     def __len__(self):
         return len(self.children)
