@@ -36,10 +36,11 @@ from PyQt5.QtCore import (Qt, QAbstractTableModel, QObject, pyqtSlot, QEvent,
 # pylint: disable=import-error
 from PyQt5.QtWidgets import (QLineEdit, QStyledItemDelegate, QToolTip,
     QMenu, QInputDialog, QMainWindow, QProgressDialog, QStyleOptionViewItem,
-    QMessageBox)
+    QMessageBox, QShortcut)
 
 # pylint: disable=import-error
-from PyQt5.QtGui import (QIcon, QPixmap, QRegExpValidator, QFont, QColor)
+from PyQt5.QtGui import (QIcon, QPixmap, QRegExpValidator, QFont, QColor,
+                         QKeySequence)
 
 from qubesmanager.about import AboutDialog
 
@@ -335,6 +336,14 @@ class QubesCache(QAbstractTableModel):
             return self._info_by_id[qid]
         return next(x for x in self._info_list if x.name == name)
 
+    def update_model_data(self, *args, **kwargs):
+        # pylint: disable=unused-argument
+        for vm_info in self._info_list:
+            # FIXME: add helper maybe?
+            # pylint: disable=protected-access
+            vm_info.vm._power_state_cache = None
+            vm_info.update()
+
     def __len__(self):
         return len(self._info_list)
 
@@ -607,27 +616,10 @@ class UpdateVMThread(common_threads.QubesThread):
                     except exc.QubesDaemonAccessError:
                         # permission denied, let us hope for the best
                         pass
-                # apply DSA-4371
-                with open('/usr/libexec/qubes-manager/dsa-4371-update', 'rb') \
-                        as dsa4371update:
-                    stdout, stderr = self.vm.run_service_for_stdio(
-                            "qubes.VMShell",
-                            user="root",
-                            input=dsa4371update.read())
-                if stdout == b'changed=yes\n':
-                    subprocess.call(
-                        ['notify-send', '-i', 'dialog-information',
-                         self.tr('Debian DSA-4371 fix installed in {}').format(
-                                self.vm.name)])
-                elif stdout == b'changed=no\n':
-                    pass
-                else:
-                    raise exc.QubesException(
-                            self.tr("Failed to apply DSA-4371 fix: {}").format(
-                                stderr.decode('ascii')))
                 self.vm.run_service("qubes.InstallUpdatesGUI",
                                     user="root", wait=False)
-        except (ChildProcessError, exc.QubesException) as ex:
+        except (ChildProcessError, subprocess.CalledProcessError,
+                exc.QubesException) as ex:
             self.msg = (self.tr("Error on qube update!"), str(ex))
 
 
@@ -640,7 +632,8 @@ class RunCommandThread(common_threads.QubesThread):
     def run(self):
         try:
             self.vm.run(self.command_to_run)
-        except (ChildProcessError, exc.QubesException) as ex:
+        except (ChildProcessError, subprocess.CalledProcessError,
+                exc.QubesException) as ex:
             self.msg = (self.tr("Error while running command!"), str(ex))
 
 class QubesProxyModel(QSortFilterProxyModel):
@@ -702,6 +695,9 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.searchbox.textChanged.connect(self.do_search)
         self.searchContainer.insertWidget(1, self.searchbox)
 
+        self.search_shortcut = QShortcut(QKeySequence('Ctrl+F'), self)
+        self.search_shortcut.activated.connect(self.searchbox.setFocus)
+
         self.settings_windows = {}
 
         self.frame_width = 0
@@ -760,8 +756,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.table.customContextMenuRequested.connect(self.open_context_menu)
 
         # Create view menu
-        for col_no in range(len(self.qubes_model.columns_indices)):
-            column = self.qubes_model.columns_indices[col_no]
+        for col_no, column in enumerate(self.qubes_model.columns_indices):
             action = self.menu_view.addAction(column)
             action.setData(column)
             action.setCheckable(True)
@@ -787,6 +782,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
 
         # Connect events
         self.dispatcher = dispatcher
+        dispatcher.add_handler('connection-established',
+                               self.qubes_cache.update_model_data)
         dispatcher.add_handler('domain-pre-start',
                                self.on_domain_status_changed)
         dispatcher.add_handler('domain-start', self.on_domain_status_changed)
@@ -1114,9 +1111,11 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         if not self.manager_settings.value("view/menubar_visible",
                                            defaultValue=True):
             self.action_menubar.setChecked(False)
+            self.menubar.setVisible(False)
         if not self.manager_settings.value("view/toolbar_visible",
                                            defaultValue=True):
             self.action_toolbar.setChecked(False)
+            self.toolbar.setVisible(False)
         if self.manager_settings.value("view/compactview",
                                            defaultValue="false") != "false":
             self.action_compact_view.setChecked(True)
@@ -1590,6 +1589,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     def action_open_console_triggered(self):
         # pylint: disable=invalid-name
         for vm in self.get_selected_vms():
+            # pylint: disable=consider-using-with
             subprocess.Popen(['qvm-console-dispvm', vm.name],
                              stdout=subprocess.DEVNULL,
                              stderr=subprocess.DEVNULL)
@@ -1631,7 +1631,6 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_manage_templates_triggered')
     def action_manage_templates_triggered(self):
-        # pylint: disable=no-self-use
         subprocess.check_call('qubes-template-manager')
 
     # noinspection PyArgumentList
@@ -1696,7 +1695,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_about_qubes_triggered')
-    def action_about_qubes_triggered(self):  # pylint: disable=no-self-use
+    def action_about_qubes_triggered(self):
         about = AboutDialog(self)
         about.exec_()
 
